@@ -402,7 +402,7 @@ def publish(
     else:
         click.echo("Published the following CVE:\n")
         print_cve_record(response_data["created"] if created else response_data["updated"])
-        click.echo(f'\nAPI response: {response_data["message"]}')
+        click.echo(f"\nAPI response: {response_data['message']}")
 
 
 @cli.command()
@@ -489,7 +489,7 @@ def publish_adp(
     else:
         click.echo("Published an ADP container for:\n")
         print_cve_record(response_data["updated"])
-        click.echo(f'\nAPI response: {response_data["message"]}')
+        click.echo(f"\nAPI response: {response_data['message']}")
 
 
 @cli.command()
@@ -597,7 +597,7 @@ def reject(
     else:
         click.echo("Rejected the following CVE:\n")
         print_cve_record(response_data["created"] if created else response_data["updated"])
-        click.echo(f'\nAPI response: {response_data["message"]}')
+        click.echo(f"\nAPI response: {response_data['message']}")
 
 
 @cli.command()
@@ -627,6 +627,43 @@ def undo_reject(ctx: click.Context, cve_id: str, print_raw: bool) -> None:
         print_cve_id(response_data["updated"])
 
 
+@cli.command()
+@click.argument("cve_id", callback=validate_cve)
+@click.option(
+    "-n",
+    "--new-cna",
+    required=True,
+    help="Shortname of the new owning CNA for the CVE ID.",
+)
+@click.option("--raw", "print_raw", default=False, is_flag=True, help="Print response JSON.")
+@click.pass_context
+@handle_cve_api_error
+def transfer(ctx: click.Context, cve_id: str, new_cna: str, print_raw: bool) -> None:
+    """Transfer ownership of a CVE ID to another CNA.
+
+    This command updates the owning_cna attribute of the specified CVE ID to transfer
+    ownership to another CNA organization. CNAs can only transfer CVE IDs they own.
+    """
+    if ctx.obj.interactive:
+        click.echo("You are about to transfer ownership of ", nl=False)
+        click.secho(cve_id, bold=True, nl=False)
+        click.echo(" to CNA ", nl=False)
+        click.secho(new_cna, bold=True, nl=False)
+        click.echo(".")
+        if not click.confirm("\nDo you want to continue?"):
+            click.echo("Exiting...")
+            sys.exit(0)
+        click.echo()
+
+    cve_api = ctx.obj.cve_api
+    response_data = cve_api.transfer(cve_id, new_cna)
+    if print_raw:
+        print_json_data(response_data)
+    else:
+        click.echo("Successfully transferred the following CVE:\n")
+        print_cve_id(response_data["updated"])
+
+
 @cli.command()
 @click.option(
     "-r",
@@ -825,7 +862,7 @@ def show_cve(
 @click.option(
     "--state",
     type=click.Choice(CveApi.States.values(), case_sensitive=False),
-    help="Filter by reservation state.",
+    help="Filter by reservation/record state.",
 )
 @click.option(
     "--reserved-lt", type=click.DateTime(), help="Filter by reservation time before timestamp."
@@ -877,6 +914,34 @@ def list_cves(
     print_table(lines, highlight_header=not no_header)
 
 
+@cli.command()
+@click.option(
+    "--state",
+    type=click.Choice(
+        [str(CveApi.States.PUBLISHED), str(CveApi.States.REJECTED)], case_sensitive=False
+    ),
+    help="Filter count by record state.",
+)
+@click.option("--raw", "print_raw", default=False, is_flag=True, help="Print response JSON.")
+@click.pass_context
+@handle_cve_api_error
+def count(ctx: click.Context, state: Optional[str], print_raw: bool) -> None:
+    """Display the total count of CVE records, optionally filtered by state.
+
+    This retrieves the count of all CVE records across all organizations, and can be
+    filtered by state (PUBLISHED, REJECTED).
+    """
+    cve_api = ctx.obj.cve_api
+    count_data = cve_api.count_cves(state=state)
+
+    if print_raw:
+        print_json_data(count_data)
+        return
+
+    state_text = f" in {state.upper()} state" if state else ""
+    click.echo(f"Total CVE records{state_text}: {count_data['totalCount']}")
+
+
 @cli.command()
 @click.option("--raw", "print_raw", default=False, is_flag=True, help="Print response JSON.")
 @click.pass_context
